# Taichi-Q

Quantum Computation Simulator Engine Based on Taichi (available for both GPU and CPU)

**This is a Hackathon Project, Projection Introduction available [here](https://bughht.github.io/University_SHU/Taichi-Q%20Introduction)**

## Intall

```
pip install taichi-q
```

## Development

Welcome any contribution!

## Example



## License

[Apach-2.0](LICENSE)